@@ -52,6 +52,7 @@
 #define RAK_FUNCTIONAL_FUN_H
 
 #include <memory>
+#include <functional>
 
 namespace rak {
 
@@ -64,13 +65,21 @@ public:
 };
 
 template <typename Result, typename Arg1>
-class function_base1 {
+class function_base1 : public std::unary_function<Arg1, Result> {
 public:
   virtual ~function_base1() {}
 
   virtual Result operator () (Arg1 arg1) = 0;
 };
 
+template <typename Result, typename Arg1, typename Arg2>
+class function_base2 : public std::binary_function<Arg1, Arg2, Result> {
+public:
+  virtual ~function_base2() {}
+
+  virtual Result operator () (Arg1 arg1, Arg2 arg2) = 0;
+};
+
 template <typename Result>
 class function0 {
 public:
@@ -105,6 +114,23 @@ private:
   std::auto_ptr<base_type> m_base;
 };
 
+template <typename Result, typename Arg1, typename Arg2>
+class function2 {
+public:
+  typedef Result                             result_type;
+  typedef function_base2<Result, Arg1, Arg2> base_type;
+
+  bool                is_valid() const     { return m_base.get() != NULL; }
+
+  void                set(base_type* base) { m_base = std::auto_ptr<base_type>(base); }
+  base_type*          release()            { return m_base.release(); }
+
+  Result operator () (Arg1 arg1, Arg2 arg2) { return (*m_base)(arg1, arg2); }
+
+private:
+  std::auto_ptr<base_type> m_base;
+};
+
 template <typename Result>
 class ptr_fn0_t : public function_base0<Result> {
 public:
@@ -133,6 +159,20 @@ private:
   Func    m_func;
 };
 
+template <typename Result, typename Arg1, typename Arg2>
+class ptr_fn2_t : public function_base2<Result, Arg1, Arg2> {
+public:
+  typedef Result (*Func)(Arg1, Arg2);
+
+  ptr_fn2_t(Func func) : m_func(func) {}
+  virtual ~ptr_fn2_t() {}
+  
+  virtual Result operator () (Arg1 arg1, Arg2 arg2) { return m_func(arg1, arg2); }
+
+private:
+  Func    m_func;
+};
+
 template <typename Object, typename Result>
 class mem_fn0_t : public function_base0<Result> {
 public:
@@ -210,6 +250,22 @@ private:
   const Arg1 m_arg1;
 };
 
+template <typename Object, typename Result, typename Arg1, typename Arg2>
+class mem_fn1_b2_t : public function_base1<Result, Arg1> {
+public:
+  typedef Result (Object::*Func)(Arg1, Arg2);
+
+  mem_fn1_b2_t(Object* object, Func func, const Arg2 arg2) : m_object(object), m_func(func), m_arg2(arg2) {}
+  virtual ~mem_fn1_b2_t() {}
+  
+  virtual Result operator () (const Arg1 arg1) { return (m_object->*m_func)(arg1, m_arg2); }
+
+private:
+  Object*    m_object;
+  Func       m_func;
+  const Arg2 m_arg2;
+};
+
 template <typename Result, typename Arg1>
 class ptr_fn0_b1_t : public function_base0<Result> {
 public:
@@ -240,6 +296,37 @@ private:
   Arg1    m_arg1;
 };
 
+template <typename Ftor>
+class ftor_fn1_t : public function_base1<typename Ftor::result_type, typename Ftor::argument_type> {
+public:
+  typedef typename Ftor::result_type result_type;
+  typedef typename Ftor::argument_type argument_type;
+
+  ftor_fn1_t(Ftor ftor) : m_ftor(ftor) {}
+  virtual ~ftor_fn1_t() {}
+  
+  virtual result_type operator () (argument_type arg1) { return m_ftor(arg1); }
+
+private:
+  Ftor    m_ftor;
+};
+
+template <typename Ftor>
+class ftor_fn2_t : public function_base2<typename Ftor::result_type, typename Ftor::first_argument_type, typename Ftor::second_argument_type> {
+public:
+  typedef typename Ftor::result_type result_type;
+  typedef typename Ftor::first_argument_type first_argument_type;
+  typedef typename Ftor::second_argument_type second_argument_type;
+
+  ftor_fn2_t(Ftor ftor) : m_ftor(ftor) {}
+  virtual ~ftor_fn2_t() {}
+  
+  virtual result_type operator () (first_argument_type arg1, second_argument_type arg2) { return m_ftor(arg1, arg2); }
+
+private:
+  Ftor    m_ftor;
+};
+
 template <typename Result>
 class value_fn0_t : public function_base0<Result> {
 public:
@@ -283,6 +370,22 @@ private:
   src_type m_object;
 };
 
+template <typename Result, typename Arg1, typename Arg2, typename SrcResult, typename SrcArg1, typename SrcArg2>
+class convert_fn2_t : public function_base2<Result, Arg1, Arg2> {
+public:
+  typedef function2<SrcResult, SrcArg1, SrcArg2> src_type;
+
+  convert_fn2_t(typename src_type::base_type* object) { m_object.set(object); }
+  virtual ~convert_fn2_t() {}
+  
+  virtual Result operator () (Arg1 arg1, Arg2 arg2) {
+    return m_object(arg1, arg2);
+  }
+
+private:
+  src_type m_object;
+};
+
 template <typename Result>
 inline function_base0<Result>*
 ptr_fn(Result (*func)()) {
@@ -295,6 +398,12 @@ ptr_fn(Result (*func)(Arg1)) {
   return new ptr_fn1_t<Result, Arg1>(func);
 }
 
+template <typename Arg1, typename Arg2, typename Result>
+inline function_base2<Result, Arg1, Arg2>*
+ptr_fn(Result (*func)(Arg1, Arg2)) {
+  return new ptr_fn2_t<Result, Arg1, Arg2>(func);
+}
+
 template <typename Result, typename Object>
 inline function_base0<Result>*
 mem_fn(Object* object, Result (Object::*func)()) {
@@ -325,6 +434,12 @@ bind_mem_fn(Object* object, Result (Object::*func)(Arg1), const Arg1 arg1) {
   return new mem_fn0_b1_t<Object, Result, Arg1>(object, func, arg1);
 }
 
+template <typename Arg1, typename Arg2, typename Result, typename Object>
+inline function_base1<Result, Arg1>*
+bind2_mem_fn(Object* object, Result (Object::*func)(Arg1, Arg2), const Arg2 arg2) {
+  return new mem_fn1_b2_t<Object, Result, Arg1, Arg2>(object, func, arg2);
+}
+
 template <typename Arg1, typename Result>
 inline function_base0<Result>*
 bind_ptr_fn(Result (*func)(Arg1), const Arg1 arg1) {
@@ -337,6 +452,18 @@ bind_ptr_fn(Result (*func)(Arg1, Arg2), const Arg1 arg1) {
   return new ptr_fn1_b1_t<Result, Arg1, Arg2>(func, arg1);
 }
 
+template <typename Ftor>
+inline function_base1<typename Ftor::result_type, typename Ftor::argument_type>*
+ftor_fn1(Ftor ftor) {
+  return new ftor_fn1_t<Ftor>(ftor);
+}
+
+template <typename Ftor>
+inline function_base2<typename Ftor::result_type, typename Ftor::first_argument_type, typename Ftor::second_argument_type>*
+ftor_fn2(Ftor ftor) {
+  return new ftor_fn2_t<Ftor>(ftor);
+}
+
 template <typename Result>
 inline function_base0<Result>*
 value_fn(const Result& val) {
@@ -381,6 +508,17 @@ convert_fn(function_base1<SrcResult, SrcArg1>* src) {
     return new convert_fn1_t<Result, Arg1, SrcResult, SrcArg1>(src);
 }
 
+template <typename Result, typename Arg1, typename Arg2, typename SrcResult, typename SrcArg1, typename SrcArg2>
+inline function_base2<Result, Arg1, Arg2>*
+convert_fn(function_base2<SrcResult, SrcArg1, SrcArg2>* src) {
+  if (equal_types_t<function_base2<Result, Arg1, Arg2>, function_base2<SrcResult, SrcArg1, SrcArg2> >::result)
+    // The pointer cast never gets done if the types are different,
+    // but needs to be here to pleasant the compiler.
+    return reinterpret_cast<typename equal_types_t<function_base2<Result, Arg1, Arg2>, function_base2<SrcResult, SrcArg1, SrcArg2> >::first_type*>(src);
+  else
+    return new convert_fn2_t<Result, Arg1, Arg2, SrcResult, SrcArg1, SrcArg2>(src);
+}
+
 }
 
 #endif
