@@ -68,6 +68,7 @@ Control::Control() :
 
   m_commandScheduler(new CommandScheduler()),
   m_variables(new utils::VariableMap()),
+  m_downloadVariables(new utils::VariableMap()),
 
   m_tick(0) {
 
@@ -79,7 +80,7 @@ Control::Control() :
 
   m_taskShutdown.set_slot(rak::mem_fn(this, &Control::handle_shutdown));
 
-  m_commandScheduler->set_slot_command(rak::mem_fn(m_variables, &utils::VariableMap::process_command));
+  m_commandScheduler->set_slot_command(rak::mem_fn(m_variables, &utils::VariableMap::process_std_single));
   m_commandScheduler->set_slot_error_message(rak::mem_fn(m_core, &core::Manager::push_log));
 }
 
@@ -89,6 +90,7 @@ Control::~Control() {
 
   delete m_commandScheduler;
   delete m_variables;
+  delete m_downloadVariables;
 
   delete m_viewManager;
 
