@@ -36,7 +36,6 @@
 
 #include "config.h"
 
-#include <stdexcept>
 #include <cstdio>
 #include <cstring>
 #include <fstream>
@@ -60,6 +59,7 @@
 
 #include "globals.h"
 #include "curl_get.h"
+#include "control.h"
 #include "download.h"
 #include "download_factory.h"
 #include "download_store.h"
@@ -167,8 +167,8 @@ Manager::handshake_log(const sockaddr* sa, int msg, int err, const torrent::Hash
 
 // Hmm... find some better place for all this.
 void
-Manager::delete_tied(Download* d) {
-  const std::string& tie = d->variable()->get_string("tied_to_file");
+Manager::delete_tied(Download* download) {
+  const std::string& tie = download->get_string("tied_to_file");
 
   // This should be configurable, need to wait for the variable
   // thingie to be implemented.
@@ -178,7 +178,7 @@ Manager::delete_tied(Download* d) {
   if (::unlink(rak::path_expand(tie).c_str()) == -1)
     push_log("Could not unlink tied file: " + std::string(rak::error_number::current().c_str()));
 
-  d->variable()->set("tied_to_file", std::string());
+  download->set("tied_to_file", std::string());
 }
 
 Manager::Manager() :
@@ -231,8 +231,8 @@ Manager::initialize_first() {
 // Most of this should be possible to move out.
 void
 Manager::initialize_second() {
-  torrent::Http::set_factory(m_pollManager->get_http_stack()->get_http_factory());
-  m_httpQueue->slot_factory(m_pollManager->get_http_stack()->get_http_factory());
+  torrent::Http::set_factory(sigc::mem_fun(m_pollManager->get_http_stack(), &CurlStack::new_object));
+  m_httpQueue->slot_factory(sigc::mem_fun(m_pollManager->get_http_stack(), &CurlStack::new_object));
 
   CurlStack::global_init();
 
@@ -242,7 +242,7 @@ Manager::initialize_second() {
   m_downloadList->slot_map_insert()["1_connect_storage_log"]  = sigc::bind(sigc::ptr_fun(&connect_signal_storage_log), sigc::mem_fun(m_logComplete, &Log::push_front));
   m_downloadList->slot_map_insert()["1_connect_tracker_dump"] = sigc::bind(sigc::ptr_fun(&connect_signal_tracker_dump), sigc::ptr_fun(&receive_tracker_dump));
 
-  m_downloadList->slot_map_erase()["1_delete_tied"] = sigc::mem_fun(this, &Manager::delete_tied);
+  m_downloadList->slot_map_erase()["9_delete_tied"] = sigc::mem_fun(this, &Manager::delete_tied);
 
   torrent::connection_manager()->set_signal_handshake_log(sigc::mem_fun(this, &Manager::handshake_log));
 }
@@ -469,7 +469,7 @@ Manager::try_create_download_expand(const std::string& uri, bool start, bool pri
 
   if (tied)
     for (std::vector<std::string>::iterator itr = paths.begin(); itr != paths.end(); )
-      if (std::find_if(m_downloadList->begin(), m_downloadList->end(), rak::equal(*itr, rak::bind2nd(std::mem_fun(&Download::variable_string), "tied_to_file")))
+      if (std::find_if(m_downloadList->begin(), m_downloadList->end(), rak::equal(*itr, rak::bind2nd(std::mem_fun(&Download::get_string), "tied_to_file")))
           != m_downloadList->end())
         itr = paths.erase(itr);
       else
@@ -492,65 +492,61 @@ Manager::receive_hashing_changed() {
   
   // Try quick hashing all those with hashing == initial, set them to
   // something else when failed.
-  for (View::iterator itr = m_hashingView->begin_visible(), last = m_hashingView->end_visible(); itr != last; ++itr)
-    try {
-
-      if ((*itr)->is_hash_checking()) {
-        foundHashing = true;
-        continue;
-      }
-
-      if ((*itr)->is_hash_checked())
-        throw torrent::internal_error("core::Manager::receive_hashing_changed() hash already checked or checking.");
+  for (View::iterator itr = m_hashingView->begin_visible(), last = m_hashingView->end_visible(); itr != last; ++itr) {
+    if ((*itr)->is_hash_checked())
+      throw torrent::internal_error("core::Manager::receive_hashing_changed() (*itr)->is_hash_checked().");
   
-      if ((*itr)->is_hash_failed() ||
-          (*itr)->variable()->get_value("hashing") != Download::variable_hashing_initial ||
-          (*itr)->download()->chunks_hashed() != 0)
-        continue;
-
-      m_downloadList->open_throw(*itr);
-      torrent::resume_load_progress(*(*itr)->download(), (*itr)->download()->bencode()->get_key("libtorrent_resume"));
-
-      if ((*itr)->download()->hash_check(true)) {
-        // Set this to exit the function so that the delayed hash done
-        // signal gets triggered before we try any real hashing.
-        foundHashing = true;
-
-      } else {
-        // Temporary hack.
-        (*itr)->download()->hash_stop();
-      }
-
-      (*itr)->variable()->set_value("hashing", Download::variable_hashing_rehash);
-
-    } catch (torrent::local_error& e) {
-      (*itr)->set_hash_failed(true);
-      push_log(e.what());
+    if ((*itr)->is_hash_checking()) {
+      foundHashing = true;
+      continue;
     }
 
-  if (foundHashing)
-    return;
+    if ((*itr)->is_hash_failed())
+      continue;
+
+    bool tryQuick =
+      (*itr)->get_value("hashing") == Download::variable_hashing_initial &&
+      (*itr)->download()->file_list()->bitfield()->empty();
+
+    if (!tryQuick && foundHashing)
+      continue;
 
-  for (View::iterator itr = m_hashingView->begin_visible(), last = m_hashingView->end_visible(); itr != last; ++itr)
     try {
-
-      if ((*itr)->is_hash_checked() || (*itr)->is_hash_checking())
-        throw torrent::internal_error("core::Manager::receive_hashing_changed() hash already checked or checking.");
-  
-      if ((*itr)->is_hash_failed())
-        continue;
-
       m_downloadList->open_throw(*itr);
-      torrent::resume_load_progress(*(*itr)->download(), (*itr)->download()->bencode()->get_key("libtorrent_resume"));
+
+      // Since the bitfield is allocated on loading of resume load or
+      // hash start, and unallocated on close, we know that if it it
+      // not empty then we have already loaded any existing resume
+      // data.
+      if ((*itr)->download()->file_list()->bitfield()->empty())
+        torrent::resume_load_progress(*(*itr)->download(), (*itr)->download()->bencode()->get_key("libtorrent_resume"));
+
+      if (tryQuick) {
+        if ((*itr)->download()->hash_check(true))
+          continue;
+
+        (*itr)->download()->hash_stop();
+
+        if (foundHashing) {
+          (*itr)->set_value("hashing", Download::variable_hashing_rehash);
+          continue;
+        }
+      }
 
       (*itr)->download()->hash_check(false);
-
-      return;
+      foundHashing = true;
 
     } catch (torrent::local_error& e) {
-      (*itr)->set_hash_failed(true);
-      push_log(e.what());
+      if (tryQuick) {
+        // Make sure we don't repeat the quick hashing.
+        (*itr)->set_value("hashing", Download::variable_hashing_rehash);
+
+      } else {
+        (*itr)->set_hash_failed(true);
+        push_log(e.what());
+      }
     }
+  }
 }
 
 }
