@@ -39,6 +39,7 @@
 #include <algorithm>
 #include <rak/functional.h>
 #include <torrent/exceptions.h>
+#include <torrent/object.h>
 
 #include "globals.h"
 
@@ -66,34 +67,32 @@ public:
 
 class ViewSortVariable : public ViewSort {
 public:
-  ViewSortVariable(const std::string& name, const std::string& value) :
-    m_name(name), m_value(value) {}
+  ViewSortVariable(const char* name, const char* value) : m_name(name), m_value(value) {}
 
   virtual bool operator () (Download* d1, Download* d2) const {
     return
-      d1->variable()->get_string(m_name) == m_value &&
-      d2->variable()->get_string(m_name) != m_value;
+      d1->get_string(m_name) == m_value &&
+      d2->get_string(m_name) != m_value;
   }
 
 private:
-  std::string m_name;
-  std::string m_value;
+  const char* m_name;
+  const char* m_value;
 };
 
 class ViewSortVariableValue : public ViewSort {
 public:
-  ViewSortVariableValue(const std::string& name, bool reverse = false) :
-    m_name(name), m_reverse(reverse) {}
+  ViewSortVariableValue(const char* name, bool reverse = false) : m_name(name), m_reverse(reverse) {}
 
   virtual bool operator () (Download* d1, Download* d2) const {
     if (m_reverse)
-      return d2->variable()->get_value(m_name) < d1->variable()->get_value(m_name);
+      return d2->get_value(m_name) < d1->get_value(m_name);
     else
-      return d1->variable()->get_value(m_name) < d2->variable()->get_value(m_name);
+      return d1->get_value(m_name) < d2->get_value(m_name);
   }
 
 private:
-  std::string m_name;
+  const char* m_name;
   bool        m_reverse;
 };
 
@@ -112,15 +111,15 @@ private:
 
 class ViewFilterVariableValue : public ViewFilter {
 public:
-  ViewFilterVariableValue(const std::string& name, torrent::Object::value_type v, bool inverse = false) :
+  ViewFilterVariableValue(const char* name, torrent::Object::value_type v, bool inverse = false) :
     m_name(name), m_value(v), m_inverse(inverse) {}
 
   virtual bool operator () (Download* d1) const {
-    return (d1->variable()->get_value(m_name) == m_value) != m_inverse;
+    return (d1->get_value(m_name) == m_value) != m_inverse;
   }
 
 private:
-  std::string                 m_name;
+  const char*                 m_name;
   torrent::Object::value_type m_value;
   bool                        m_inverse;
 };
@@ -191,7 +190,7 @@ ViewManager::build_sort_list(const sort_args& args) {
   sortList.reserve(args.size());
 
   for (sort_args::const_iterator itr = args.begin(), last = args.end(); itr != last; ++itr) {
-    sort_map::const_iterator sortItr = m_sort.find(*itr);
+    sort_map::const_iterator sortItr = m_sort.find(itr->c_str());
 
     if (sortItr == m_sort.end())
       throw torrent::input_error("Invalid sorting identifier.");
@@ -235,7 +234,7 @@ ViewManager::build_filter_list(const filter_args& args) {
   filterList.reserve(args.size());
 
   for (filter_args::const_iterator itr = args.begin(), last = args.end(); itr != last; ++itr) {
-    filter_map::const_iterator filterItr = m_filter.find(*itr);
+    filter_map::const_iterator filterItr = m_filter.find(itr->c_str());
 
     if (filterItr == m_filter.end())
       throw torrent::input_error("Invalid filtering identifier.");
