@@ -51,7 +51,10 @@
 #include <torrent/peer/client_info.h>
 
 #include "core/download.h"
+#include "core/manager.h"
 
+#include "control.h"
+#include "globals.h"
 #include "utils.h"
 
 namespace display {
@@ -156,8 +159,8 @@ print_download_info(char* first, char* last, core::Download* d) {
   }
 
   first = print_buffer(first, last, " [%c%c R: %3.2f",
-                       d->variable()->get_string("tied_to_file").empty() ? ' ' : 'T',
-                       d->variable()->get_value("ignore_commands") == 0 ? ' ' : 'I',
+                       d->get_string("tied_to_file").empty() ? ' ' : 'T',
+                       d->get_value("ignore_commands") == 0 ? ' ' : 'I',
                        d->download()->bytes_done() > 0 ? (double)(100 * d->download()->up_rate()->total() / d->download()->bytes_done()) / 100 : 0.0);
 
   if (d->priority() != 2)
@@ -175,7 +178,7 @@ char*
 print_download_status(char* first, char* last, core::Download* d) {
   if (d->is_active())
     ;
-  else if (d->variable_value("hashing") != 0)
+  else if (d->get_value("hashing") != 0)
     first = print_buffer(first, last, "Hashing: ");
   else if (!d->is_active())
     first = print_buffer(first, last, "Inactive: ");
@@ -279,11 +282,15 @@ print_status_info(char* first, char* last) {
 }
 
 char*
-print_status_extra(char* first, char* last, __UNUSED Control* c) {
+print_status_extra(char* first, char* last) {
   first = print_buffer(first, last, " [U %i/%i]",
                        torrent::currently_unchoked(),
                        torrent::max_unchoked());
 
+  first = print_buffer(first, last, " [H %u/%u]",
+                       control->core()->get_poll_manager()->get_http_stack()->active(),
+                       control->core()->get_poll_manager()->get_http_stack()->max_active());                       
+
   first = print_buffer(first, last, " [S %i/%i/%i]",
                        torrent::total_handshakes(),
                        torrent::connection_manager()->size(),
