@@ -48,7 +48,7 @@
 namespace display {
 
 WindowHttpQueue::WindowHttpQueue(core::HttpQueue* q) :
-  Window(new Canvas, false, 1),
+  Window(new Canvas, 0, 0, 1, extent_full, 1),
   m_queue(q) {
   
   set_active(false);
@@ -72,10 +72,10 @@ WindowHttpQueue::redraw() {
   m_canvas->erase();
   m_canvas->print(0, 0, "Http [%i]", m_queue->size());
 
-  int pos = 10;
+  unsigned int pos = 10;
   Container::iterator itr = m_container.begin();
 
-  while (itr != m_container.end() && pos + 20 < m_canvas->get_width()) {
+  while (itr != m_container.end() && pos + 20 < m_canvas->width()) {
     if (itr->m_http == NULL)
       m_canvas->print(pos, 0, "%s done", itr->m_name.c_str());
 
@@ -83,9 +83,7 @@ WindowHttpQueue::redraw() {
       m_canvas->print(pos, 0, "%s ---%%", itr->m_name.c_str());
 
     else
-      m_canvas->print(pos, 0, "%s %3i%%",
-		      itr->m_name.c_str(),
-		      (int)(100.0 * itr->m_http->size_done() / itr->m_http->size_total()));
+      m_canvas->print(pos, 0, "%s %3i%%", itr->m_name.c_str(), (int)(100.0 * itr->m_http->size_done() / itr->m_http->size_total()));
 
     pos += itr->m_name.size() + 6;
     ++itr;
@@ -100,7 +98,8 @@ WindowHttpQueue::cleanup_list() {
     else
       ++itr;
 
-  mark_dirty();
+  // Bad, can't have this here as it is called from redraw().
+  //   mark_dirty();
 }
 
 std::string
@@ -140,8 +139,7 @@ WindowHttpQueue::receive_insert(core::CurlGet* h) {
 
 void
 WindowHttpQueue::receive_erase(core::CurlGet* h) {
-  Container::iterator itr = std::find_if(m_container.begin(), m_container.end(),
-					 rak::equal(h, std::mem_fun_ref(&Node::get_http)));
+  Container::iterator itr = std::find_if(m_container.begin(), m_container.end(), rak::equal(h, std::mem_fun_ref(&Node::get_http)));
 
   if (itr == m_container.end())
     throw std::logic_error("WindowHttpQueue::receive_erase(...) tried to remove an object we don't have");
