@@ -38,15 +38,17 @@
 
 #include <stdexcept>
 #include <rak/socket_address.h>
-#include <torrent/block_transfer.h>
 #include <torrent/rate.h>
-#include <torrent/piece.h>
+#include <torrent/data/block_transfer.h>
+#include <torrent/data/piece.h>
+#include <torrent/peer/client_list.h>
+#include <torrent/peer/peer_info.h>
 
 #include "core/download.h"
 #include "rak/algorithm.h"
 
 #include "canvas.h"
-#include "client_info.h"
+#include "utils.h"
 #include "window_peer_list.h"
 
 namespace display {
@@ -89,7 +91,7 @@ WindowPeerList::redraw() {
                                            m_list->end(),
                                            m_canvas->height() - y);
 
-  if (m_download->download()->chunks_total() <= 0)
+  if (m_download->download()->file_list()->size_chunks() <= 0)
     throw std::logic_error("WindowPeerList::redraw() m_slotChunksTotal() returned invalid value");
 
   while (range.first != range.second) {
@@ -107,7 +109,7 @@ WindowPeerList::redraw() {
     m_canvas->print(x, y, "%.1f", (double)p.peer_rate()->rate() / 1024); x += 7;
 
     m_canvas->print(x, y, "%c/%c%c/%c%c",
-                    p.is_incoming() ? 'r' : 'l',
+                    p.is_encrypted() ? (p.is_incoming() ? 'R' : 'L') : (p.is_incoming() ? 'r' : 'l'),
                     p.is_remote_choked() ? 'c' : 'u',
                     p.is_remote_interested() ? 'i' : 'n',
                     p.is_local_choked() ? 'c' : 'u',
@@ -138,7 +140,7 @@ WindowPeerList::redraw() {
     x += 7;
 
     char buf[128];
-    control->client_info()->print(buf, buf + 128, p.id().c_str());
+    print_client_version(buf, buf + 128, p.info()->client_info());
 
     m_canvas->print(x, y, "%s", buf);
 
@@ -149,7 +151,7 @@ WindowPeerList::redraw() {
 
 int
 WindowPeerList::done_percentage(torrent::Peer& p) {
-  int chunks = m_download->download()->chunks_total();
+  int chunks = m_download->download()->file_list()->size_chunks();
 
   return chunks ? (100 * p.chunks_done()) / chunks : 0;
 }
