@@ -56,6 +56,8 @@
 #include "display/window_log.h"
 #include "display/window_title.h"
 
+#include "utils/variable_map.h"
+
 #include "control.h"
 #include "download.h"
 #include "download_list.h"
@@ -283,12 +285,12 @@ DownloadList::receive_exit_input(Input type) {
       if (current_view()->focus() == current_view()->end_visible())
         throw torrent::input_error("No download in focus to change root directory.");
 
-      (*current_view()->focus())->variable()->set("directory", rak::trim(input->str()));
-      control->core()->push_log("New root directory \"" + (*current_view()->focus())->variable()->get_string("directory") + "\" for torrent.");
+      (*current_view()->focus())->set("directory", rak::trim(input->str()));
+      control->core()->push_log("New root directory \"" + (*current_view()->focus())->get_string("directory") + "\" for torrent.");
       break;
 
     case INPUT_COMMAND:
-      control->variable()->process_command(input->str());
+      control->variable()->process_std_single(input->str());
       break;
 
     default:
